# Copyright (C) 2021,2022,2023 Kian-Meng Ang
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

"""Config for English (en) language."""

DEFAULT_RE_TITLE = r"Title:(.*)"
DEFAULT_RE_AUTHOR = r"Author:(.*)"
DEFAULT_RE_TAG = r"Tags：(.*)"
DEFAULT_RE_VOLUME = r"(Volume.*)"
DEFAULT_RE_CHAPTER = r"(Chapter.*)"
